@@ -66,16 +66,17 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--libdir=/usr/lib/arm-linux-gnueabihf' '--enable-ipv6' "
                 "'--enable-loadable-sqlite-extensions' "
                 "'--with-dbmliborder=bdb:gdbm' '--with-computed-gotos' "
-                "'--without-ensurepip' '--with-system-expat' '--with-dtrace' "
+                "'--without-ensurepip' '--with-system-expat' "
                 "'--with-ssl-default-suites=openssl' "
                 "'--with-wheel-pkg-dir=/usr/share/python-wheels/' "
-                "'MKDIR_P=/bin/mkdir -p' 'CC=arm-linux-gnueabihf-gcc'",
+                "'MKDIR_P=/bin/mkdir -p' '--with-dtrace' "
+                "'CC=arm-linux-gnueabihf-gcc'",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.12',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/build/python3.12-uTY0YI/python3.12-3.12.3/build-shared/coverage.info',
+ 'COVERAGE_INFO': '/build/python3.12-i1eZw1/python3.12-3.12.7/build-shared/coverage.info',
  'COVERAGE_LCOV_OPTIONS': '--rc lcov_branch_coverage=1',
- 'COVERAGE_REPORT': '/build/python3.12-uTY0YI/python3.12-3.12.3/build-shared/lcov-report',
+ 'COVERAGE_REPORT': '/build/python3.12-i1eZw1/python3.12-3.12.7/build-shared/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--rc lcov_branch_coverage=1 --branch-coverage '
                             '--title "CPython 3.12 LCOV report [commit $(shell '
                             ')]"',
@@ -157,7 +158,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_BROKEN_SEM_GETVALUE': 0,
  'HAVE_BROKEN_UNSETENV': 0,
  'HAVE_BUILTIN_ATOMIC': 1,
- 'HAVE_BZLIB_H': 1,
+ 'HAVE_BZLIB_H': 0,
  'HAVE_CHFLAGS': 0,
  'HAVE_CHMOD': 1,
  'HAVE_CHOWN': 1,
@@ -369,7 +370,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_LONG_DOUBLE': 1,
  'HAVE_LSTAT': 1,
  'HAVE_LUTIMES': 1,
- 'HAVE_LZMA_H': 1,
+ 'HAVE_LZMA_H': 0,
  'HAVE_MADVISE': 1,
  'HAVE_MAKEDEV': 1,
  'HAVE_MBRTOWC': 1,
@@ -430,7 +431,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_PWRITE': 1,
  'HAVE_PWRITEV': 1,
  'HAVE_PWRITEV2': 1,
- 'HAVE_READLINE_READLINE_H': 1,
+ 'HAVE_READLINE_READLINE_H': 0,
  'HAVE_READLINK': 1,
  'HAVE_READLINKAT': 1,
  'HAVE_READV': 1,
@@ -446,7 +447,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_RL_COMPLETION_SUPPRESS_APPEND': 1,
  'HAVE_RL_PRE_INPUT_HOOK': 1,
  'HAVE_RL_RESIZE_TERMINAL': 1,
- 'HAVE_RPC_RPC_H': 0,
+ 'HAVE_RPC_RPC_H': 1,
  'HAVE_RTPSPAWN': 0,
  'HAVE_SCHED_GET_PRIORITY_MAX': 1,
  'HAVE_SCHED_H': 1,
@@ -602,8 +603,8 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_UTMP_H': 1,
  'HAVE_UUID_CREATE': 0,
  'HAVE_UUID_ENC_BE': 0,
- 'HAVE_UUID_GENERATE_TIME_SAFE': 0,
- 'HAVE_UUID_H': 0,
+ 'HAVE_UUID_GENERATE_TIME_SAFE': 1,
+ 'HAVE_UUID_H': 1,
  'HAVE_UUID_UUID_H': 0,
  'HAVE_VFORK': 1,
  'HAVE_WAIT': 1,
@@ -619,7 +620,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_WORKING_TZSET': 1,
  'HAVE_WRITEV': 1,
  'HAVE_ZLIB_COPY': 1,
- 'HAVE_ZLIB_H': 1,
+ 'HAVE_ZLIB_H': 0,
  'HAVE__GETPTY': 0,
  'HOSTRUNNER': '',
  'HOST_GNU_TYPE': 'armv7l-unknown-linux-gnueabihf',
@@ -636,7 +637,9 @@ build_time_vars = {'ABIFLAGS': '',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'arm-linux-gnueabihf-g++ -shared -Wl,-O1 '
-                '-Wl,-Bsymbolic-functions',
+                '-Wl,-Bsymbolic-functions -Wl,-Bsymbolic-functions '
+                ' -Wl,-z,relro -g '
+                '-fwrapv -O2   ',
  'LDFLAGS': '-Wl,-Bsymbolic-functions  '
             '-Wl,-z,relro -g -fwrapv -O2   '
             '',
@@ -750,13 +753,13 @@ build_time_vars = {'ABIFLAGS': '',
                    '_xxsubinterpreters  _xxinterpchannels  _zoneinfo  audioop  '
                    '_decimal  _bz2  _lzma  _dbm  _gdbm  readline  _codecs_cn  '
                    '_codecs_hk  _codecs_iso2022  _codecs_jp  _codecs_kr  '
-                   '_codecs_tw  _multibytecodec  _crypt  mmap  ossaudiodev  '
-                   'resource  termios  _posixshmem  _multiprocessing  _ctypes  '
-                   '_curses  _curses_panel  _sqlite3  _ssl  _hashlib  '
-                   'xxsubtype  _xxtestfuzz  _testbuffer  _testinternalcapi  '
-                   '_testcapi  _testclinic  _testimportmultiple  '
-                   '_testmultiphase  _testsinglephase  _ctypes_test  '
-                   'xxlimited  xxlimited_35',
+                   '_codecs_tw  _multibytecodec  _crypt  mmap  nis  '
+                   'ossaudiodev  resource  termios  _posixshmem  '
+                   '_multiprocessing  _ctypes  _curses  _curses_panel  '
+                   '_sqlite3  _ssl  _hashlib  _uuid  _tkinter  xxsubtype  '
+                   '_xxtestfuzz  _testbuffer  _testinternalcapi  _testcapi  '
+                   '_testclinic  _testimportmultiple  _testmultiphase  '
+                   '_testsinglephase  _ctypes_test  xxlimited  xxlimited_35',
  'MODDISABLED_NAMES': '',
  'MODLIBS': '-lm      -lm   -lz -lm -lm   -lexpat  -lexpat     '
             'Modules/_hacl/libHacl_Hash_SHA2.a         -lz',
@@ -793,12 +796,13 @@ build_time_vars = {'ABIFLAGS': '',
                     '_xxsubinterpreters _xxinterpchannels _zoneinfo audioop '
                     '_decimal _bz2 _lzma _dbm _gdbm readline _codecs_cn '
                     '_codecs_hk _codecs_iso2022 _codecs_jp _codecs_kr '
-                    '_codecs_tw _multibytecodec _crypt mmap ossaudiodev '
+                    '_codecs_tw _multibytecodec _crypt mmap nis ossaudiodev '
                     'resource termios _posixshmem _multiprocessing _ctypes '
-                    '_curses _curses_panel _sqlite3 _ssl _hashlib xxsubtype '
-                    '_xxtestfuzz _testbuffer _testinternalcapi _testcapi '
-                    '_testclinic _testimportmultiple _testmultiphase '
-                    '_testsinglephase _ctypes_test xxlimited xxlimited_35',
+                    '_curses _curses_panel _sqlite3 _ssl _hashlib _uuid '
+                    '_tkinter xxsubtype _xxtestfuzz _testbuffer '
+                    '_testinternalcapi _testcapi _testclinic '
+                    '_testimportmultiple _testmultiphase _testsinglephase '
+                    '_ctypes_test xxlimited xxlimited_35',
  'MODULE_ARRAY_LDFLAGS': '',
  'MODULE_ARRAY_STATE': 'yes',
  'MODULE_ATEXIT_LDFLAGS': '',
@@ -823,7 +827,9 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE_MATH_LDFLAGS': '-lm',
  'MODULE_MATH_STATE': 'yes',
  'MODULE_MMAP_STATE': 'yes',
- 'MODULE_NIS_STATE': 'missing',
+ 'MODULE_NIS_CFLAGS': '-I/usr/include/tirpc',
+ 'MODULE_NIS_LDFLAGS': '-lnsl -ltirpc',
+ 'MODULE_NIS_STATE': 'yes',
  'MODULE_OBJS': '\\',
  'MODULE_OSSAUDIODEV_LDFLAGS': '',
  'MODULE_OSSAUDIODEV_STATE': 'yes',
@@ -834,7 +840,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE_PYEXPAT_DEPS': '',
  'MODULE_PYEXPAT_LDFLAGS': '-lexpat',
  'MODULE_PYEXPAT_STATE': 'yes',
- 'MODULE_READLINE_CFLAGS': '',
+ 'MODULE_READLINE_CFLAGS': '-D_DEFAULT_SOURCE',
  'MODULE_READLINE_LDFLAGS': '-lreadline',
  'MODULE_READLINE_STATE': 'yes',
  'MODULE_RESOURCE_STATE': 'yes',
@@ -922,15 +928,15 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__CSV_STATE': 'yes',
  'MODULE__CTYPES_CFLAGS': '-fno-strict-overflow',
  'MODULE__CTYPES_DEPS': '../Modules/_ctypes/ctypes.h',
- 'MODULE__CTYPES_LDFLAGS': '-lffi -ldl',
+ 'MODULE__CTYPES_LDFLAGS': '-lffi  -ldl',
  'MODULE__CTYPES_MALLOC_CLOSURE': '',
  'MODULE__CTYPES_STATE': 'yes',
  'MODULE__CTYPES_TEST_LDFLAGS': '-lm',
  'MODULE__CTYPES_TEST_STATE': 'yes',
- 'MODULE__CURSES_CFLAGS': '',
- 'MODULE__CURSES_LDFLAGS': '-lncursesw',
- 'MODULE__CURSES_PANEL_CFLAGS': '',
- 'MODULE__CURSES_PANEL_LDFLAGS': '-lpanelw -lncursesw',
+ 'MODULE__CURSES_CFLAGS': '-D_DEFAULT_SOURCE',
+ 'MODULE__CURSES_LDFLAGS': '-lncursesw -ltinfo',
+ 'MODULE__CURSES_PANEL_CFLAGS': '-D_DEFAULT_SOURCE  -D_DEFAULT_SOURCE',
+ 'MODULE__CURSES_PANEL_LDFLAGS': '-lpanelw  -lncursesw -ltinfo',
  'MODULE__CURSES_PANEL_STATE': 'yes',
  'MODULE__CURSES_STATE': 'yes',
  'MODULE__DATETIME_LDFLAGS': '-lm',
@@ -951,9 +957,9 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__GDBM_CFLAGS': '',
  'MODULE__GDBM_LDFLAGS': '-lgdbm',
  'MODULE__GDBM_STATE': 'yes',
- 'MODULE__HASHLIB_CFLAGS': '-I/usr/include',
+ 'MODULE__HASHLIB_CFLAGS': '',
  'MODULE__HASHLIB_DEPS': '../Modules/hashlib.h',
- 'MODULE__HASHLIB_LDFLAGS': '-L/usr/lib   -lcrypto',
+ 'MODULE__HASHLIB_LDFLAGS': '-lcrypto',
  'MODULE__HASHLIB_STATE': 'yes',
  'MODULE__HEAPQ_LDFLAGS': '',
  'MODULE__HEAPQ_STATE': 'yes',
@@ -1020,12 +1026,12 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__SQLITE3_LDFLAGS': '-lsqlite3',
  'MODULE__SQLITE3_STATE': 'yes',
  'MODULE__SRE_LDFLAGS': '',
- 'MODULE__SSL_CFLAGS': '-I/usr/include',
+ 'MODULE__SSL_CFLAGS': '',
  'MODULE__SSL_DEPS': '../Modules/_ssl.h ../Modules/_ssl/cert.c '
                      '../Modules/_ssl/debughelpers.c ../Modules/_ssl/misc.c '
                      '../Modules/_ssl_data.h ../Modules/_ssl_data_111.h '
                      '../Modules/_ssl_data_300.h ../Modules/socketmodule.h',
- 'MODULE__SSL_LDFLAGS': '-L/usr/lib  -lssl -lcrypto',
+ 'MODULE__SSL_LDFLAGS': '-lssl -lcrypto',
  'MODULE__SSL_STATE': 'yes',
  'MODULE__STATISTICS_LDFLAGS': '-lm',
  'MODULE__STATISTICS_STATE': 'yes',
@@ -1043,11 +1049,16 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__TESTINTERNALCAPI_STATE': 'yes',
  'MODULE__TESTMULTIPHASE_STATE': 'yes',
  'MODULE__THREAD_LDFLAGS': '',
- 'MODULE__TKINTER_STATE': 'missing',
+ 'MODULE__TKINTER_CFLAGS': '-I/usr/include/tcl8.6  -Wno-strict-prototypes '
+                           '-DWITH_APPINIT=1',
+ 'MODULE__TKINTER_LDFLAGS': '-ltk8.6 -ltkstub8.6 -ltcl8.6 -ltclstub8.6',
+ 'MODULE__TKINTER_STATE': 'yes',
  'MODULE__TRACEMALLOC_LDFLAGS': '',
  'MODULE__TYPING_LDFLAGS': '',
  'MODULE__TYPING_STATE': 'yes',
- 'MODULE__UUID_STATE': 'missing',
+ 'MODULE__UUID_CFLAGS': '-I/usr/include/uuid',
+ 'MODULE__UUID_LDFLAGS': '-luuid',
+ 'MODULE__UUID_STATE': 'yes',
  'MODULE__WEAKREF_LDFLAGS': '',
  'MODULE__XXINTERPCHANNELS_STATE': 'yes',
  'MODULE__XXSUBINTERPRETERS_STATE': 'yes',
@@ -1187,7 +1198,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': '@READELF@',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python3.12-uTY0YI/python3.12-3.12.3/build-shared',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python3.12-i1eZw1/python3.12-3.12.7/build-shared',
  'SCRIPTDIR': '/usr/lib',
  'SCRIPT_2TO3': 'build/scripts-3.12/2to3-3.12',
  'SCRIPT_IDLE': 'build/scripts-3.12/idle3.12',
@@ -1217,6 +1228,7 @@ build_time_vars = {'ABIFLAGS': '',
                'Modules/_multibytecodec.cpython-312-arm-linux-gnueabihf.so '
                'Modules/_crypt.cpython-312-arm-linux-gnueabihf.so '
                'Modules/mmap.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/nis.cpython-312-arm-linux-gnueabihf.so '
                'Modules/ossaudiodev.cpython-312-arm-linux-gnueabihf.so '
                'Modules/resource.cpython-312-arm-linux-gnueabihf.so '
                'Modules/termios.cpython-312-arm-linux-gnueabihf.so '
@@ -1228,6 +1240,8 @@ build_time_vars = {'ABIFLAGS': '',
                'Modules/_sqlite3.cpython-312-arm-linux-gnueabihf.so '
                'Modules/_ssl.cpython-312-arm-linux-gnueabihf.so '
                'Modules/_hashlib.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_uuid.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_tkinter.cpython-312-arm-linux-gnueabihf.so '
                'Modules/xxsubtype.cpython-312-arm-linux-gnueabihf.so '
                'Modules/_xxtestfuzz.cpython-312-arm-linux-gnueabihf.so '
                'Modules/_testbuffer.cpython-312-arm-linux-gnueabihf.so '
@@ -1281,10 +1295,10 @@ build_time_vars = {'ABIFLAGS': '',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python3.12-uTY0YI/python3.12-3.12.3/build-shared '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python3.12-i1eZw1/python3.12-3.12.7/build-shared '
                './python -E',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python3.12-uTY0YI/python3.12-3.12.3/build-shared '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python3.12-i1eZw1/python3.12-3.12.7/build-shared '
                './python -E ../Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'idlelib/idle_test \\',
  'TESTTIMEOUT': 1200,
@@ -1315,8 +1329,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/build/python3.12-uTY0YI/python3.12-3.12.3/build-shared',
- 'abs_srcdir': '/build/python3.12-uTY0YI/python3.12-3.12.3/build-shared/..',
+ 'abs_builddir': '/build/python3.12-i1eZw1/python3.12-3.12.7/build-shared',
+ 'abs_srcdir': '/build/python3.12-i1eZw1/python3.12-3.12.7/build-shared/..',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
